@@ -3,19 +3,33 @@ import sqlite3
 import datetime
 import asyncio
 import queue
+import os
+import json
 from threadwrapper import *
-from filehandling import join_path, abs_main_dir
-from encryptedsocket import SC as ESC, SS as ESS
-from unencryptedsocket import SC as USC, SS as USS
 from easyrsa import *
-from omnitools import args, key_pair_format
+from omnitools import args, key_pair_format, join_path, abs_main_dir
 
 
 __ALL__ = ["SqlQueue"]
 
 
-class SqlQueue(object):
+class SqlQueue:
     def worker(self, _db) -> None:
+        def bak_path(db):
+            now = datetime.datetime.now()
+            a, b = os.path.splitext(os.path.basename(db))
+            c = os.path.join(
+                os.path.dirname(db),
+                "bak",
+                str(now.year),
+                str(now.month).zfill(2),
+                str(now.day).zfill(2),
+                str(now.hour).zfill(2),
+                str(now.minute).zfill(2),
+                "{}.{}.{}".format(a, int(time.time()*1000), b)
+            )
+            os.makedirs(os.path.dirname(c), exist_ok=True)
+            return c
         def connect_db(db):
             conn = sqlite3.connect(db)
             self.__exc(conn, "PRAGMA locking_mode=EXCLUSIVE;")
@@ -31,50 +45,47 @@ class SqlQueue(object):
             if journal_mode == "wal":
                 self.__exc(conn, "PRAGMA wal_checkpoint(PASSIVE);")
         def backup(db):
-            now = datetime.datetime.now()
-            new_db = os.path.join(
-                os.path.dirname(db),
-                "bak",
-                str(now.year),
-                str(now.month).zfill(2),
-                str(now.day).zfill(2),
-                str(now.hour).zfill(2),
-                str(now.minute).zfill(2),
-                os.path.splitext(os.path.basename(db))[0]+".{}.db".format(int(time.time()*1000))
-            )
-            os.makedirs(os.path.dirname(new_db), exist_ok=True)
-            shutil.copy(db, new_db)
+            new_db = bak_path(db)
+            shutil.copyfile(db, new_db)
         def do_backup(conn):
             disconnect_db(conn)
             backup(_db)
             self.do_backup = False
             return connect_db(_db)
-        conn = connect_db(_db)
-        if self.auto_backup:
-            conn = do_backup(conn)
-        prev_commit_ts = time.time()
-        prev_backup_ts = time.time()
-        while not self.terminate:
-            time_commit_diff = (time.time()-prev_commit_ts)*1000
-            time_backup_diff = (time.time()-prev_backup_ts)*1000
-            if self.do_commit or time_commit_diff > self.timeout_commit:
-                commit_db(conn)
-                self.do_commit = False
-                prev_commit_ts = time.time()
-            elif self.do_backup or (self.auto_backup and (time_backup_diff > self.timeout_backup)):
+        try:
+            conn = connect_db(_db)
+            if self.auto_backup:
                 conn = do_backup(conn)
-                prev_backup_ts = time.time()
-            elif self.sqlq.qsize() > 0:
-                tid, sql, data, row_factory = self.sqlq.get()
-                self.exc_result[tid] = self.__exc(conn, sql, data, row_factory)
-                # self.sqlq.task_done()
-            time.sleep(1/1000)
-        disconnect_db(conn)
-        if self.auto_backup:
-            backup(_db)
+            prev_commit_ts = time.time()
+            prev_backup_ts = time.time()
+            while not self.terminate:
+                time_commit_diff = (time.time()-prev_commit_ts)*1000
+                time_backup_diff = (time.time()-prev_backup_ts)*1000
+                if self.do_commit or time_commit_diff > self.timeout_commit:
+                    commit_db(conn)
+                    self.do_commit = False
+                    prev_commit_ts = time.time()
+                elif self.do_backup or (self.auto_backup and (time_backup_diff > self.timeout_backup)):
+                    conn = do_backup(conn)
+                    prev_backup_ts = time.time()
+                elif self.sqlq.qsize() > 0:
+                    tid, sql, data, row_factory = self.sqlq.get()
+                    self.exc_result[tid] = self.__exc(conn, sql, data, row_factory)
+                    # self.sqlq.task_done()
+                time.sleep(1/1000)
+            disconnect_db(conn)
+            if self.auto_backup:
+                backup(_db)
+        except:
+            self.ioerror = True
+            self.exploded_reason = traceback.format_exc()
+            queue_left = []
+            while self.sqlq.qsize():
+                queue_left.append(self.sqlq.get())
+            open(bak_path(_db)+".queue", "wb").write(json.dumps(queue_left).encode())
         self.worker_dead = True
 
-    def __exc(self, conn: sqlite3.Connection, sql: str, data: tuple = (), row_factory: str = "row") -> Any:
+    def __exc(self, conn: sqlite3.Connection, sql: str, data: tuple = (), row_factory: str = "row"):
         mode = ""
         try:
             if row_factory == "list":
@@ -146,7 +157,7 @@ class SqlQueue(object):
             self,
             server: bool = False, db: str = "",
             timeout_commit: int = 60*1000, auto_backup: bool = False, timeout_backup: int = 60*1000,
-            depth: int = 2, export_functions = None
+            export_functions = None
     ) -> None:
         self.is_server = server
         self.do_commit = False
@@ -164,8 +175,6 @@ class SqlQueue(object):
         self.exploded_reason = None
         self.sc = None
         if self.is_server:
-            if not os.path.isabs(db):
-                db = join_path(abs_main_dir(depth=int(depth)), db)
             self.timeout_commit = timeout_commit
             self.auto_backup = auto_backup
             self.timeout_backup = timeout_backup
@@ -213,7 +222,7 @@ class SqlQueue(object):
             return self.sc().request(command=_cmd, data=args(sql, data, row_factory))
 
     def sql_(self, exc_type: str, sql: str, data: tuple = (), row_factory: str = "row",
-            result: Any = None, key: Any = None, _cmd: str = "sql") -> list:
+            result= None, key= None, _cmd: str = "sql") -> list:
         if result is None:
             result = {}
         if key is None:
@@ -259,47 +268,43 @@ class SqlQueue(object):
 
 class SqlQueueE(SqlQueue):
     def __init__(self, host = "127.199.71.10", db_port: int = None, key_pair: key_pair_format = None, **kwargs) -> None:
-        if "db" in kwargs:
-            if not os.path.isabs(kwargs["db"]):
-                kwargs["db"] = join_path(abs_main_dir(depth=int(kwargs["depth"])), kwargs["db"])
         super().__init__(**kwargs)
         port = db_port if db_port else 39292
+        from encryptedsocket import SC, SS
         if self.is_server:
             if key_pair is None:
                 key_pair = EasyRSA(bits=1024).gen_key_pair()
-            self.ess = ESS(key_pair, self.functions, host, port, True)
-            thread = threading.Thread(target=self.ess.start)
+            self.ss = SS(key_pair, self.functions, host, port, True)
+            thread = threading.Thread(target=self.ss.start)
             thread.daemon = True
             thread.start()
         else:
-            self.sc = lambda : ESC(host, port)
+            self.sc = lambda: SC(host, port)
 
     def stop(self):
         super().stop()
         if self.is_server:
-            self.ess.stop()
+            self.ss.stop()
         return True
 
 
 class SqlQueueU(SqlQueue):
     def __init__(self, host = "127.199.71.10", db_port: int = None, **kwargs) -> None:
-        if "db" in kwargs:
-            if not os.path.isabs(kwargs["db"]):
-                kwargs["db"] = join_path(abs_main_dir(depth=int(kwargs["depth"])), kwargs["db"])
         super().__init__(**kwargs)
         port = db_port if db_port else 39292
+        from unencryptedsocket import SC, SS
         if self.is_server:
-            self.uss = USS(self.functions, host, port, True)
-            thread = threading.Thread(target=self.uss.start)
+            self.ss = SS(self.functions, host, port, True)
+            thread = threading.Thread(target=self.ss.start)
             thread.daemon = True
             thread.start()
         else:
-            self.sc = lambda : USC(host, port)
+            self.sc = lambda: SC(host, port)
 
     def stop(self):
         super().stop()
         if self.is_server:
-            self.uss.stop()
+            self.ss.stop()
         return True
 
 
