@@ -1,7 +1,7 @@
 import sqlq
 
 
-sqlqueue = sqlq.SqlQueueU(server=True, db="db.db", depth=2)
+sqlqueue = sqlq.SqlQueueU(server=True, db="db.db")
 input("stop? ")
 sqlqueue.commit()
 sqlqueue.stop()
