@@ -20,7 +20,7 @@ async def _sql_async(j, loop, result, key):
     result[key] = await sqlqueue._sql_async(id(j), "INSERT INTO `test` VALUES (?);", (j,), loop=loop)
 
 
-sqlqueue = SqlQueueU(server=True, db=r"db.db", depth=2, timeout_backup=10000, auto_backup=True)
+sqlqueue = SqlQueueU(server=True, db=r"db.db", timeout_backup=10000, auto_backup=True)
 for func in [_sql, _sql_async, sql, sql_async]:
     for j in [1,2**5,2**6,2**7,2**8,2**9]:
         loop = asyncio.new_event_loop()
